check_data — skchange

Skip to main content
`Ctrl`+`K`

# check_data

check_data(X: DataFrame | Series | ndarray, min_length: int, min_length_name: str = 'min_length', allow_missing_values: bool = False) → DataFrame

  Check if input data is valid.

  Parameters:
    Xpd.DataFrame, pd.Series

      Input data to check.

    min_lengthint

      Minimum number of samples in X.

    min_length_namestr, optional (default=”min_length”)

      Name of min_length parameter to be shown in the error message.

    allow_missing_valuesbool, optional (default=False)

      Whether to allow missing values in X.

  Returns:
    Xpd.DataFrame

      Input data in pd.DataFrame format.